@@ -889,18 +889,12 @@ PluginConfig = Dict[str, Any]
 JSONValue = Union[str, int, float, bool, Dict[str, Any], List[Any]]
 
 
-class ToastMessage(TypedDict, total=False):
-    toast: str
-
-
 class BasePlugin(ABC):
     @abstractmethod
     def __init__(self, logger: PluginLogger, api_instance: PluginAPI) -> None: ...
     @abstractmethod
-    def on_form_submit(
+    async def on_form_submit(
         self, action_id: str, payload: Any
-    ) -> ToastMessage | Coroutine[Any, Any, ToastMessage]: ...
+    ) -> Dict[Literal["toastMessage"], str]: ...
     @abstractmethod
-    def configure_cameras(
-        self, cameras: List[CameraDevice]
-    ) -> None | Coroutine[Any, Any, None]: ...
+    async def configure_cameras(self, cameras: List[CameraDevice]) -> None: ...
